module Remenv
  class IO
    attr_reader :adapter

    def initialize(adapter)
      @adapter = adapter
    end

    def dump(filename)
      write(File.open(filename, 'w+'))
    end

    def load(filename)
      adapter.clear!

      File.open(filename, 'r') do |file|
        read(file)
      end
    end

    def read(handle)
      pairs = handle.each_with_object({}) do |line, hash|
        raw_key, raw_val  = line.split(/\s*=\s*/)

        next if raw_key.nil? || raw_val.nil?

        key = raw_key.sub(/^export /i, '')
        val = raw_val.strip.gsub(/'|"/, '')

        hash[key] = val
      end

      adapter.set(pairs)
    end

    def write(handle, leader: 'export')
      handle.tap do |io|
        adapter.show.each do |key, value|
          io << %(#{leader} #{key}="#{value}"\n)
        end

        io.rewind
      end
    end
  end
end
